@@ -6,7 +6,6 @@ knitr::opts_chunk$set(
 
 ## ----demonstration1------------------------------------------------------
 library(iCiteR)
-
 get_metrics('27599104')
 
 
@@ -19,3 +18,9 @@ dat <- icite_api('27599104')
 
 print(dat)
 
+## ----demonstration4, error=TRUE------------------------------------------
+icite_api('42')
+
+## ----demonstration5------------------------------------------------------
+dat_2012 <- search_metrics(year=2012, offset = '18000000', limit = '50')
+
